#ifndef CalendarCell_h
#define CalendarCell_h
// $Id: CalendarCell.h,v 1.10 2014/11/25 15:41:31 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QDate>
#include <QRectF>
#include <QList>
#include <algorithm>

namespace Calendar
{
    //! store cells (date and rect
    class Cell: public Counter
    {

        public:

        //! constructor
        Cell( void ):
            Counter( "Calendar::Cell" ),
            enabled_( false )
        {}

        //! constructor
        Cell( QDate date, QRectF rect );

        //!@name accessors
        //@{

        //! valid
        bool isValid( void ) const
        { return date_.isValid() && !rect_.isNull(); }

        //! date
        const QDate& date( void ) const
        { return date_; }

        //! rect
        const QRectF& rect( void ) const
        { return rect_; }

        //! rect


        //! enabled
        const bool& isEnabled( void ) const
        { return enabled_; }

        //@}

        //! enabled
        void setEnabled( const bool& value )
        { enabled_ = value; }

        //! used to find cell that match a given point
        class ContainsFTor
        {
            public:

            //! constructor
            ContainsFTor( const QPoint& point ):
                point_( point )
             {}

            //! predicate
            bool operator() (const Cell& cell ) const
            { return cell.rect().contains( point_ ); }

            private:

            //! prediction
            QPoint point_;

        };

        class List: public QList<Cell>, public Counter
        {
            public:

            //! empty constructor
            List( void ):
                Counter( "Cell::List" )
                {}

            //! filled constructor
            List( const QList<Cell>& other ):
                QList<Cell>( other ),
                Counter( "Cell::List" )
            {}

            //! find date matching point
            Cell find( const QPoint& position ) const
            {
                const_iterator iter = std::find_if( begin(), end(), ContainsFTor( position ) );
                return iter == end() ? Cell():*iter;
            }

            //! find cells matching given week
            List selectWeek( const QDate& date )
            {
                if( !date.isValid() ) return List();
                List out;
                foreach( const Cell& cell, *this )
                { if( cell.date().weekNumber() == date.weekNumber() ) out << cell; }

                return out;
            }

            //! find cells matching given week day
            List selectWeekDay( const QDate& date )
            {
                if( !date.isValid() ) return List();
                List out;
                foreach( const Cell& cell, *this )
                { if( cell.date().dayOfWeek() == date.dayOfWeek() ) out << cell; }

                return out;
            }

        };

        private:

        //! date
        QDate date_;

        //! active
        bool enabled_;

        //!rect
        QRectF rect_;

    };

}

#endif
