#ifndef EditAlarmDialog_h
#define EditAlarmDialog_h

// $Id: EditAlarmDialog.h,v 1.14 2014/02/10 10:07:45 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/*!
\file EditAlarmDialog.h
\brief Edit/create alarm popup dialog
\author Hugo Pereira
\version $Revision: 1.14 $
\date $Date: 2014/02/10 10:07:45 $
*/

#include "Alarm.h"
#include "CustomDialog.h"
#include "Debug.h"

#include <QCheckBox>
#include <QLabel>
#include <QPushButton>
#include <QTimeEdit>
#include <QToolButton>

class TextEditor;

namespace Clock
{
    //! Edit/create alarm popup dialog
    class EditAlarmDialog: public CustomDialog
    {

        Q_OBJECT

        public:

        //! constructor
        EditAlarmDialog( QWidget* );

        //! destructor
        virtual ~EditAlarmDialog( void )
        {}

        //! alarm
        void setAlarm( const Alarm& );

        //! alarm
        Alarm alarm( void ) const;

        protected Q_SLOTS:

        //! edit selected days
        void _editDays( void );

        //! show alarm dialog
        void _preview( void );

        //! repeat
        void _setRepeat( const Alarm& )
        {
            // just for debugging
            Debug::Throw( "Clock::EditAlarmDialog::_setRepeat.\n" );
        }

        //! repeat
        void _unsetRepeat( const Alarm& )
        {
            // just for debugging
            Debug::Throw( "Clock::EditAlarmDialog::_unsetRepeat.\n" );
        }

        protected:

        //! update days label
        void updateDaysLabel( void ) const
        { daysLabel_->setText( Alarm::dayNames( days_ ) ); }

        private:

        //! hours spinbox
        QTimeEdit* timeEditor_;

        //! selected days
        unsigned int days_;

        //! enabled days label
        QLabel* daysLabel_;

        //! enabled days button
        QToolButton* editDays_;

        //! text
        TextEditor* editor_;

        //! enable checkbox
        QCheckBox* enabledCheckbox_;

    };

};

#endif
