// $Id: DataSamples.cpp,v 1.11 2014/02/10 10:07:45 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/*!
  \file    DataSamples.cpp
  \brief   data samples container
  \author  Hugo Pereira
  \version $Revision: 1.11 $
  \date    $Date: 2014/02/10 10:07:45 $
*/

#include "DataSamples.h"
#include "Debug.h"

namespace Disk
{

    //________________________________________________
    void DataSamples::setSampleSize( unsigned int sampleSize )
    {
        sampleSize_ = sampleSize;
        while( sampleList_.size() > sampleSize_ )
        { sampleList_.removeFirst(); }
    }

    //________________________________________________
    void DataSamples::setDataSize( unsigned int dataSize )
    {
        dataSize_ = dataSize;
        while( dataList_.size() > dataSize_ )
        { dataList_.removeFirst(); }
    }

    //_________________________________________________________________
    void DataSamples::add( const Data& data )
    {

        Debug::Throw(2) << "DataSamples::add - " << " dataSize=" << dataSize_ << " sampleSize=" << sampleSize_ << endl;

        // add data to samples
        sampleList_ << data;

        // check size
        if( sampleList_.size() > sampleSize_ )
        {

            Data data( sampleList_.back()- sampleList_.front() );
            if( data.valid() ) dataList_ << data;
            if( dataList_.size() > dataSize_ ) dataList_.removeFirst();
            sampleList_.removeFirst();

            Debug::Throw(2) << "DataSamples::add - " << data << endl;

        }

        return;

    }

}
