// $Id: DiskLoad_26.cpp,v 1.23 2014/02/10 22:11:42 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "DiskLoad_26.h"
#include "Debug.h"

#include <QFile>
#include <QStringList>
#include <QTextStream>

namespace Disk
{

    //________________________________________________
    DiskLoad_26::DiskLoad_26( void ):
        filename_( "/proc/diskstats" )
    {}

    //________________________________________________
    void DiskLoad_26::update( void )
    {

        // open file
        QFile in( filename_ );
        if( !in.open( QIODevice::ReadOnly ) )
        {
            Debug::Throw( "DiskLoad_26::update - cannot open file.\n" );
            return;
        }

        QStringList lines( QString( in.readAll() ).split( "\n" ) );
        for( QStringList::iterator iter = lines.begin(); iter != lines.end(); ++iter )
        {

            DiskId id;
            Data data;
            QTextStream stream( &*iter );
            stream >> id;
            if( id.valid() )
            {
                QString device;
                unsigned long
                    r, r_merge, r_sect, r_ticks,
                    w, w_merge, w_sect, w_ticks;
                stream
                    >> device
                    >> r >> r_merge >> r_sect >> r_ticks
                    >> w >> w_merge >> w_sect >> w_ticks;

                data = Data( r_sect, w_sect );
                data.setTime( _timer().elapsed()/1000 );
                data.setValid( stream.status() == QTextStream::Ok );
                if( data.valid() )
                {

                    if( _sampleMap().find( id ) == _sampleMap().end() )
                    {

                        _sampleMap()[ id ].setSampleSize( _sampleSize() );
                        _sampleMap()[ id ].setDataSize( _dataSize() );
                        _diskIds()[ device ] = id;

                    }

                    _sampleMap()[id].add( data );

                }

            }

        }

        return;

    }
}
