#ifndef DiskWidget_h
#define DiskWidget_h

// $Id: DiskWidget.h,v 1.30 2015/01/08 17:04:20 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "DataSamples.h"
#include "DiskMonitor.h"

#include "GridLayoutItem.h"
#include "HistogramWidget.h"

#include <QAction>
#include <QActionGroup>
#include <QPainter>
#include <QBasicTimer>
#include <QTimerEvent>
#include <QMap>

//! disk widgets
namespace Disk {

    //! transparent disk load widget
    class DiskWidget : public HistogramWidget
    {

        //! Qt meta object functions
        Q_OBJECT

        public:

        //! constructor
        DiskWidget( QWidget* = 0 );

        //! destructor
        virtual ~DiskWidget( void )
        {}

        protected:

        //! context menu
        virtual void _installContextMenuActions( BaseContextMenu* );

        //* tooltip widget
        virtual BaseToolTipWidget* _createToolTipWidget( void );

        //! tooltip
        virtual bool _updateToolTip( void );

        //!@name event handlers
        //@{

        //! timer
        void timerEvent( QTimerEvent* );

        //! paint event [overloaded]
        void _paint( QPaintDevice&, const QRect& );

        //! resize event [overloaded]
        void resizeEvent( QResizeEvent* );

        //@}

        protected Q_SLOTS:

        //! opend configuration dialog
        virtual void _configuration( void );

        //! update configuration
        virtual void _updateConfiguration( void );

        //! toggle inverse colors
        virtual void _toggleInverseColors( bool );

        private Q_SLOTS:

        //! toggle display
        void _toggleDisplay( QAction* );

        protected:

        //! update display actions from mask
        void _updateDisplayActions( void );

        //! scale factor
        double _getScale( const DataSamples::DataList& ) const;

        //! draw load text
        void _paintLoad( QPainter&, QRect& );

        //! set default colors
        void _setDefaultColors( void );

        private:

        //! install actions
        void _installActions( void );

        //! cpu monitor
        DiskMonitor diskMonitor_;

        //!@name actions
        //@{

        //! display actions
        QActionGroup* displayActionGroup_;

        //! display actions
        using DisplayActionMap = QMap<QAction*, Data::Type>;

        //! display actions
        DisplayActionMap displayActions_;

        //@}

        //!@name properties
        //@{

        //! display mask
        Data::Types displayMask_;

        //! color map
        using ColorMap = QMap< Data::Type, Color >;

        //! color map
        ColorMap colorMap_;

        //@}

        //* tooltip items
        GridLayoutItem::List toolTipItems_;

    };
}

#endif
