// $Id: ToolTipWidget.cpp,v 1.26 2015/01/09 15:40:28 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ToolTipWidget.h"

#include "Debug.h"
#include "QtUtil.h"

#include <QLayout>

//_________________________________________
ToolTipWidget::ToolTipWidget( QWidget* parent ):
    BaseToolTipWidget( parent )
{

    Debug::Throw( "ToolTipWidget::ToolTipWidget.\n" );

    // create objects
    QHBoxLayout *hLayout = new QHBoxLayout();
    hLayout->setMargin(10);
    hLayout->setSpacing(10);
    setLayout( hLayout );

    hLayout->addWidget( pixmapLabel_ = new QLabel(this), Qt::AlignTop );

    // right side layout
    QVBoxLayout* vLayout = new QVBoxLayout();
    vLayout->setMargin( 0 );
    vLayout->setSpacing( 5 );
    vLayout->addStretch( 1 );

    hLayout->addLayout( vLayout );

    // title
    vLayout->addWidget( titleLabel_ = new QLabel( this ) );
    titleLabel_->setAlignment( Qt::AlignCenter );
    titleLabel_->setFont( QtUtil::titleFont( titleLabel_->font() ) );
    titleLabel_->setMargin( 1 );

    // separator
    vLayout->addWidget( separator_ = new QFrame( this ) );
    separator_->setFrameStyle( QFrame::HLine );

    // grid layout
    vLayout->addLayout( vLayout_ = new QVBoxLayout() );
    vLayout_->setMargin(0);
    vLayout->addStretch( 1 );

    // hide title by default
    titleLabel_->hide();
    separator_->hide();

}

//_________________________________________
void ToolTipWidget::setTitle( const QString& title )
{
    if( title.isEmpty() )
    {

        titleLabel_->hide();
        separator_->hide();

    } else {

        titleLabel_->show();
        separator_->show();
        titleLabel_->setText( title );

    }

}
