#ifndef EditPictureDialog_h
#define EditPictureDialog_h

// $Id: EditPictureDialog.h,v 1.9 2014/02/10 10:07:45 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BrowsedLineEditor.h"
#include "CustomDialog.h"
#include "PictureAttributes.h"

#include <QCheckBox>
#include <QLabel>
#include <QSpinBox>

namespace Pictures
{
    //! local browsed line editor, that uses ImageFileDialog for browsing
    class PictureEditor: public BrowsedLineEditor
    {
        Q_OBJECT

        public:

        //! constructor
        PictureEditor( QWidget* parent ):
            BrowsedLineEditor( parent )
        {}

        protected Q_SLOTS:

        //! browse filesystem (overloaded)
        virtual void _browse( void );

    };


    //! Edit/create picture popup dialog
    class EditPictureDialog: public CustomDialog
    {

        Q_OBJECT

            public:

            //! constructor
            EditPictureDialog( QWidget* parent );

        //! destructor
        virtual ~EditPictureDialog( void )
        {}

        //! picture
        void setAttributes( const PictureAttributes& );

        //! picture
        PictureAttributes attributes( void ) const;

        private Q_SLOTS:

        //! update icon
        void _updateIcon( void );

        private:

        //! icon label
        QLabel* iconLabel_;

        //! picture editor
        PictureEditor* editor_;

        //! width editor
        QSpinBox* widthSpinBox_;

        //! height editor
        QSpinBox* heightSpinBox_;

        //! visibility
        QCheckBox* visibilityCheckBox_;

        //! attributes
        PictureAttributes attributes_;

    };

};

#endif
