
// $Id: SummaryConfigurationDialog.cpp,v 1.32 2014/09/26 08:06:19 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SummaryConfigurationDialog.h"
#include "SummaryConfigurationDialog.moc"

#include "GridLayout.h"
#include "BaseIconNames.h"
#include "IconEngine.h"
#include "OptionBrowsedLineEditor.h"
#include "OptionCheckBox.h"
#include "OptionComboBox.h"
#include "OptionSlider.h"
#include "OptionSpinBox.h"

#include <QGroupBox>
#include <QLabel>
#include <QLayout>

namespace Summary
{

    //_________________________________________________________
    SummaryConfigurationDialog::SummaryConfigurationDialog( QWidget* parent ):
        ConfigurationDialog( parent )
    {

        Debug::Throw( "SummaryConfigurationDialog::SummaryConfigurationDialog.\n" );
        setWindowTitle( tr( "Configuration - System Monitor Summary" ) );

        // generic widgets
        QWidget* page;
        QGroupBox *box;
        OptionCheckBox* checkbox;

        page = &addPage( IconEngine::get( IconNames::PreferencesUnsorted ), tr( "Unsorted" ), tr( "Additional unsorted settings" ) );
        page->layout()->addWidget( box = new QGroupBox( tr( "Display" ), page ));

        QVBoxLayout* boxLayout( new QVBoxLayout() );
        boxLayout->setSpacing(5);
        boxLayout->setMargin(5);
        box->setLayout( boxLayout );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Hostname" ), box, "SHOW_HOST" ) );
        checkbox->setToolTip( tr( "Show/hide hostname" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Date" ), box, "SHOW_DATE" ) );
        checkbox->setToolTip( tr( "Show/hide date" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Time" ), box, "SHOW_TIME" ) );
        checkbox->setToolTip( tr( "Show/hide time" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "CPU" ), box, "SHOW_CPU" ) );
        checkbox->setToolTip( tr( "Show/hide cpu usage" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Memory" ), box, "SHOW_MEMORY" ) );
        checkbox->setToolTip( tr( "Show/hide memory usage" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Disk" ), box, "SHOW_DISK" ) );
        checkbox->setToolTip( tr( "Show/hide disk usage" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Network" ), box, "SHOW_NETWORK" ) );
        checkbox->setToolTip( tr( "Show/hide network transfer" ) );
        addOptionWidget( checkbox );

        boxLayout->addWidget( checkbox = new OptionCheckBox( tr( "Temperature" ), box, "SHOW_TEMPERATURE" ) );
        checkbox->setToolTip( tr( "Show/hide cpu temperature" ) );
        addOptionWidget( checkbox );

        // misc
        page->layout()->addWidget( box = new QGroupBox( tr( "Unsorted" ), page ));
        boxLayout = new QVBoxLayout();
        boxLayout->setSpacing(5);
        boxLayout->setMargin(5);
        box->setLayout( boxLayout );

        boxLayout->addWidget( checkbox = new OptionCheckBox(  tr( "Use lm-sensors" ), box, "USE_LM_SENSORS" ) );
        checkbox->setToolTip( tr( "Use lm-sensors to get temperatures" ) );
        checkbox->setChecked( true );
        addOptionWidget( checkbox );

        GridLayout* gridLayout = new GridLayout();
        gridLayout->setSpacing(5);
        gridLayout->setMargin(0);
        gridLayout->setMaxCount( 2 );
        boxLayout->addLayout( gridLayout );

        QLabel* label;
        OptionBrowsedLineEditor* editor;
        gridLayout->addWidget( label = new QLabel( tr( "Lm-sensors command:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "LM_SENSORS" ) );
        addOptionWidget( editor );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
        label->setBuddy( editor );

        connect( checkbox, SIGNAL(toggled(bool)), editor, SLOT(setEnabled(bool)) );

        gridLayout->addWidget( label = new QLabel( tr( "ACPI file:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ACPI_FILE" ) );
        addOptionWidget( editor );
        editor->setEnabled( false );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
        label->setBuddy( editor );
        connect( checkbox, SIGNAL(toggled(bool)), editor, SLOT(setDisabled(bool)) );

        gridLayout->addWidget( label = new QLabel( tr( "Acpi command:" ), box ) );
        gridLayout->addWidget( editor = new OptionBrowsedLineEditor( box, "ACPI" ) );
        addOptionWidget( editor );
        addOptionWidget( editor );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
        label->setBuddy( editor );

        OptionSpinBox* spinbox;
        gridLayout->addWidget( label = new QLabel( tr( "Refresh interval:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "REFRESH_RATE" ) );
        spinbox->setSuffix( tr( "s" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Time interval (seconds) between two refresh" ) );
        addOptionWidget( spinbox );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
        label->setBuddy( spinbox );

        gridLayout->addWidget( label = new QLabel( tr( "Number of samples:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "SAMPLES" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Number of samples averaged for each measurement" ) );
        addOptionWidget( spinbox );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
        label->setBuddy( spinbox );

        gridLayout->addWidget( new QLabel( tr( "Network device check interval" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "NETWORK_AUTO_SELECT_RATE" ) );
        spinbox->setSuffix( tr( "s" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Time interval (seconds) between checks" ) );
        addOptionWidget( spinbox );

        gridLayout->addWidget( label = new QLabel( tr( "Delay:" ), box ) );
        gridLayout->addWidget( spinbox = new OptionSpinBox( box, "CLOCK_DELAY" ) );
        spinbox->setSuffix( tr( "h" ) );
        spinbox->setMinimum( -24 );
        spinbox->setMaximum( 24 );
        spinbox->setToolTip( "Add hours delay" );
        addOptionWidget( spinbox );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
        label->setBuddy( spinbox );

        OptionComboBox *combobox;
        gridLayout->addWidget( label = new QLabel( tr( "Kernel version:" ), box ) );
        gridLayout->addWidget( combobox = new OptionComboBox( box, "KERNEL_VERSION" ) );
        combobox->setUseValue( false );
        combobox->addItem( tr( "2.4" ) );
        combobox->addItem( tr( "2.6 or above" ) );
        combobox->setToolTip( tr( "Linux kernel version" ) );
        addOptionWidget( combobox );
        label->setAlignment(Qt::AlignVCenter|Qt::AlignRight);
        label->setBuddy( combobox );

        read();
    }

}
